@@ -162,7 +162,9 @@ private:
      * @brief isSpcialPlatform 是否当前是特殊平台
      * (特殊平台下需要进行不同的获取桌面图像的方式如wayland，以后考虑枚举方式)
      */
-    static bool    isSpcialPlatform();
+    static bool    isWaylandPlatform();
+
+    void autoUpdate();
 
 private:
     ELanchType                 _isLaunchByDBus = ELanchedBySelf;
@@ -175,6 +177,8 @@ private:
     QPixmap                    _desktopPixmap;
     QTimer                    *_updateScreenshotTimer = nullptr;
     QPoint                     _pos;
+
+    QPixmap                    _cursorPix;
     friend class CScreenshotWidget;
 };
 #endif // CPICKERMANAGER_H
